@@ -42,8 +42,14 @@
 #define R3LEN 9
 #define R4LEN 7
 
+bool shutting=false;
+
 MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const char * name, WFlags f ) : ResizableDragWidget ( parent,name,f ), stand_alone(tren)
 {
+
+	
+	tray=0;
+
 	nresize=false;
 	
 	display=qt_xdisplay();
@@ -68,7 +74,8 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const ch
 	int sty=15;
 	extent_visible=false;
 
-	resize ( 550,235 );
+// 	resize ( 550,235 );
+// 	move(0,0);
 
 	VButton *esc = new VButton ( this,"" );
 	esc->setKeyCode ( 9 );
@@ -504,6 +511,7 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const ch
 
 		mnu_dock = m->insertItem ( "Dock widget", this, SLOT ( showDock() ) );
 		bool show_dock = cfg->readBoolEntry("showdock",false);
+		
 		m->setItemChecked(mnu_dock, show_dock);
 		
 		//m->insertItem("Configure", this, SLOT(config()));
@@ -515,22 +523,95 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const ch
 		dock = new KbdDock ( this );
 		if (show_dock){
 			dock->show();
+			
 		}
 		else{
 			dock->hide();
+	
 		}
 		
 		QFont fnt = cfg->readFontEntry("KvkbdFont");
 		m->setItemChecked(mnu_autores, fnt_autores);
 
 		setFont(fnt);
+
+		popup_menu = new VButton ( this,"popupmenu" );
+		popup_menu->resize ( 15,30 );
+		popup_menu->move ( 525,15+35 );
+		//popup_menu->setPaletteBackgroundColor ( Qt::green );
+		popup_menu->res();
+		
+		popup_menu->setPixmap(QIconSet(SmallIcon("configure")).pixmap());
+
+		other_keys.append(popup_menu);
+		connect ( popup_menu,SIGNAL ( clicked() ),this, SLOT ( showConfigMenu() ) );
+		
 	}
 	else{
 		setCaption("kvkbdalone");
+		
 	}
 	
 }
 
+
+void MainWidget::finishInit()
+{
+	KConfig *cfg = KApplication::kApplication()->config();
+	bool vis = cfg->readBoolEntry("visible",true);
+	if (vis) {
+		show();
+	}
+	else {
+		hide();
+	}
+}
+bool MainWidget::close(bool alsoDelete)
+{
+	shutting=true;
+	saveState();
+	return QWidget::close(alsoDelete);
+}
+
+void MainWidget::restorePosition()
+{	
+	QDesktopWidget *desktop = QApplication::desktop();
+	QRect screen_geom = desktop->screenGeometry();
+
+	int d_width=550;
+	int d_height=235;
+	QRect dflt_geom(screen_geom.width()-d_width,screen_geom.height()-d_height,d_width,d_height);
+
+	KConfig *cfg = 0;
+	cfg = KApplication::kApplication()->config();
+	if (cfg){
+		QRect geom  = cfg->readRectEntry("geometry");
+		if (!geom.isNull() && geom.isValid()) {
+			dflt_geom=geom;
+		}
+	}
+	setGeometry(dflt_geom);
+}
+void MainWidget::saveState()
+{
+	KConfig *cfg = 0;
+	cfg = KApplication::kApplication()->config();
+	if (cfg){
+		cfg->writeEntry("visible",isShown());
+		cfg->sync();
+	}
+}
+void MainWidget::hideEvent ( QHideEvent * )
+{
+	
+	KConfig *cfg = 0;
+	cfg = KApplication::kApplication()->config();
+	if (cfg){
+		cfg->writeEntry("geometry",geometry());
+		cfg->sync();
+	}
+}
+
 void MainWidget::resizeEvent(QResizeEvent * e)
 {
 
@@ -576,13 +657,20 @@ void MainWidget::resizeEvent(QResizeEvent * e)
 	updateFont();
 	
 }
+void MainWidget::showConfigMenu()
+{
+	if (tray){
+		KPopupMenu *m = tray->contextMenu();
+		m->popup(mapToGlobal(popup_menu->pos()));
+	}
+}
 void MainWidget::updateFont()
 {
 	if (tray->contextMenu()->isItemChecked(mnu_autores)){
 		QFont fnt = this->font();
 		fnt.setWeight(QFont::Bold);	
 		//double rs = (100.0/700.0)*width();
-		double rp = (8.0/700.0)*width();
+		double rp = (8.0/600.0)*width();
 		//fnt.setStretch(rs);
 		fnt.setPointSizeFloat(rp);
 		setFont(fnt);
@@ -617,8 +705,8 @@ void MainWidget::chooseFont()
     QFont font = QFontDialog::getFont(
                     &ok, this->font(), this );
     if ( ok ) {
-        // font is set to the font the user selected
-		setFont(font);
+			// font is set to the font the user selected
+			setFont(font);
     } else {
         // the user canceled the dialog; font is set to the initial
         // value, in this case Helvetica [Cronyx], 10
@@ -1736,3 +1824,14 @@ void KbdTray::mousePressEvent(QMouseEvent *e)
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
